package com.css.simulation.resource.system.service;

import api.common.pojo.constants.DictConstants;
import api.common.pojo.constants.LogConstants;
import api.common.pojo.param.system.SceneImportPageParam;
import api.common.pojo.po.system.SceneImportPO;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.common.utils.PoUtil;
import com.css.simulation.resource.log.service.LogService;
import com.css.simulation.resource.system.mapper.SceneImportMapper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
@Slf4j
public class SceneImportService {

    @Resource
    DictService dictService;
    @Resource
    LogService logService;
    @Resource
    SceneImportMapper sceneImportMapper;

    public SceneImportPO saveTask(SceneImportPO po) {
        // 名称校验
        List<SceneImportPO> list = sceneImportMapper.checkName(po);
        if (ObjectUtil.isNotNull(list)) {
            po.setId(null);
            return po;
        }
        // 常规字段赋值
        PoUtil.initAddPo(po);
        String id = po.getId();
        po.setStatus(DictConstants.SCENE_IMPORT_STATUS_0); //重置状态
        if (ObjectUtil.isNull(id)) { // 新增场景导入任务
            po.setId(StringUtil.getRandomUUID());
            sceneImportMapper.insert(po);
            // 记录日志
            Map<String, String> dictMap = dictService.getDictMapByType(DictConstants.SCENE_TYPE);
            String type = dictMap.get(po.getSceneType());
            String content = "创建" + type + "上传任务:" + po.getName() + "(ID:" + po.getId() + ")";
            logService.logSceneUpload(LogConstants.SYS_LOG_SCENE_TASK_INSERT, content);
            log.info(content);
        } else {
            sceneImportMapper.update(po);
        }
        return po;
    }


    public void updateStatus(SceneImportPO params) {
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        sceneImportMapper.updateStatus(params);
    }

    public void update(SceneImportPO params) {
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        sceneImportMapper.update(params);
    }

    public void updateInfo(SceneImportPO params) {
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        sceneImportMapper.updateInfo(params);
    }

    public PageInfo<SceneImportPO> getSceneImporPagetList(SceneImportPageParam param) {
        PageUtil.setPageInfo(param);
        List<SceneImportPO> list = sceneImportMapper.getSceneImporPagetList(param);
        //字典翻译
        Map<String, Map<String, String>> dictMaps = dictService.getDictMapsByTypes(DictConstants.SCENE_TYPE + "," + DictConstants.SCENE_IMPORT_STATUS);
        list.forEach(po -> {
            po.setSceneType(dictMaps.get(DictConstants.SCENE_TYPE).get(po.getSceneType()));
            po.setStatus(dictMaps.get(DictConstants.SCENE_IMPORT_STATUS).get(po.getStatus()));
        });
        return new PageInfo<>(list);
    }

    public void deleteTask(String taskId) {
//        //1 根据任务 id 查询场景类型
//        String sceneType = sceneImportMapper.selectSceneTypeByTaskId(taskId);
//        SceneImportPO sceneImportPO = SceneImportPO.builder()
//
//                .build();
//        //2 根据任务id删除相关联的所有同名任务
//        if (DictConstants.SCENE_NATURAL.equals(sceneType)) {
//            sceneImportMapper.deleteNaturalByTaskId(taskId);
//        } else if (DictConstants.SCENE_STANDARD.equals(sceneType)) {
//            sceneImportMapper.deleteNaturalByTaskId(taskId);
//        } else if (DictConstants.SCENE_ACCIDENT.equals(sceneType)) {
//            sceneImportMapper.deleteNaturalByTaskId(taskId);
//        } else if (DictConstants.SCENE_GENERAL.equals(sceneType)) {
//            sceneImportMapper.deleteNaturalByTaskId(taskId);
//        } else {
//            throw new RuntimeException("场景类型错误：" + sceneType);
//        }
//        //2 删除任务
    }
}
